==> flask_sketch-0.3.0-py3-none-any.whl: flask_sketch/questions/auth_framework.py <==
from flask_sketch.utils import has_answers

auth_framework_questions = [
    {
        "type": "list",
        "message": "Select the Authentication Framework",
        "name": "auth_framework",
        "choices": [
            {
                "name": "Flask-Security-Too (aka Flask-Security)",
                "value": "security_web",
            },
            {
                "name": "Flask-Login",
                "value": "login_web",
                "disabled": "Not supported yet",
            },
            {
                "name": "Flask-BasicAuth",
                "value": "basicauth_web",
                "disabled": "Not supported yet",
            },
            {"name": "None", "value": "none", "disabled": "Not supported yet"},
        ],
        "when": lambda answers: has_answers(
            answers, have={"application_type": "web_only"}
        ),
        "validate": lambda answer: "You must choose at least one topping."
        if len(answer) == 0
        else True,
    },
    {
        "type": "list",
        "message": "Select the Authentication Framework",
        "name": "auth_framework",
        "choices": [
            {"name": "Flask-JWT-Extended", "value": "jwt_extended"},
            {"name": "Flask-BasicAuth", "value": "basicauth_api"},
            {
                "name": "Flask-Praetorian",
                "value": "praetorian",
                "disabled": "Not yet supported",
            },
            {"name": "None", "value": "none"},
        ],
        "when": lambda answers: has_answers(
            answers, have={"application_type": "api_only"}
        ),
        "validate": lambda answer: "You must choose at least one topping."
        if len(answer) == 0
        else True,
    },
    {
        "type": "list",
        "message": "Select the Authentication Framework",
        "name": "auth_framework",
        "choices": [
            {
                "name": "Flask-Security-Too + Flask-JWT-Extended",
                "value": "security_jwt_extended",
            },
            {
                "name": "Flask-Login + Flask-JWT-Extended",
                "value": "login_jwt_extended",
            },
            {"name": "Flask-BasicAuth", "value": "basicauth_web_api"},
            {"name": "None", "value": "none"},
        ],
        "when": lambda answers: has_answers(
            answers, have={"application_type": "web_and_api"}
        ),
        "validate": lambda answer: "You must choose at least one topping."
        if len(answer) == 0
        else True,
    },
]

==> flask_sketch-0.3.13-py3-none-any.whl: flask_sketch/questions/auth_framework.py <==
from flask_sketch.utils import has_answers

auth_framework_questions = [
    {
        "type": "list",
        "message": "Select the Authentication Framework",
        "name": "auth_framework",
        "choices": [
            {
                "name": "Flask-Security-Too (aka Flask-Security)",
                "value": "security",
            },
            {"name": "Flask-Login", "value": "login"},
            {
                "name": "Flask-BasicAuth",
                "value": "basicauth",
                "disabled": "Not supported yet",
            },
            {"name": "None", "value": "none", "disabled": "Not supported yet"},
        ],
        "validate": lambda answer: "You must choose at least one topping."
        if len(answer) == 0
        else True,
    },
    {
        "type": "list",
        "message": "Select the Authentication Framework",
        "name": "api_auth_framework",
        "choices": [
            {"name": "Flask-JWT-Extended", "value": "jwt_extended"},
            {
                "name": "Flask-BasicAuth",
                "value": "basicauth",
                "disabled": "Not yet supported",
            },
            {
                "name": "Flask-Praetorian",
                "value": "praetorian",
                "disabled": "Not yet supported",
            },
            {"name": "None", "value": "none"},
        ],
        "when": lambda answers: has_answers(answers, have={"have_api": True}),
        "validate": lambda answer: "You must choose at least one topping."
        if len(answer) == 0
        else True,
    },
]
